@@ -14,9 +14,9 @@ describe 'panko::wsgi::apache' do
         :path                => '/',
         :servername          => facts[:fqdn],
         :ssl                 => true,
-        :threads             => facts[:os_workers],
+        :threads             => 1,
         :user                => 'panko',
-        :workers             => 1,
+        :workers             => facts[:os_workers],
         :wsgi_daemon_process => 'panko',
         :wsgi_process_group  => 'panko',
         :wsgi_script_dir     => platform_params[:wsgi_script_path],
@@ -55,7 +55,7 @@ describe 'panko::wsgi::apache' do
         :path                      => '/',
         :servername                => 'dummy.host',
         :ssl                       => false,
-        :threads                   => facts[:os_workers],
+        :threads                   => 1,
         :user                      => 'panko',
         :workers                   => 8,
         :wsgi_daemon_process       => 'panko',
